.. vim: spell

Command Reference
******************

All inmanta commands and services are started by the ``inmanta`` command. This page provides an
overview of all subcommands available:

inmanta
#########

.. argparse::
   :module: inmanta.app
   :func: cmd_parser
   :prog: inmanta

inmanta-cli
###########

Use ``inmanta-cli --help``
